@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2005-2014 Open Source Applications Foundation.
+ * Copyright (c) 2005-2015 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,6 +32,10 @@
 
 #include <Python.h>
 
+#if !defined(PYPY_VERSION) && defined(PYPY_VERSION_NUM)
+#define PYPY_VERSION
+#endif
+
 #if PY_VERSION_HEX < 0x02040000
 #define Py_RETURN_NONE return Py_INCREF(Py_None), Py_None
 #define Py_RETURN_TRUE return Py_INCREF(Py_True), Py_True
@@ -87,12 +91,16 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/unistr.h>
 #include <unicode/ucnv.h>
 #include <unicode/locid.h>
+#include <unicode/uloc.h>
 #include <unicode/resbund.h>
 #include <unicode/calendar.h>
 #include <unicode/gregocal.h>
 #include <unicode/format.h>
 #include <unicode/datefmt.h>
 #include <unicode/smpdtfmt.h>
+#include <unicode/udat.h>
+#include <unicode/udatpg.h>
+#include <unicode/dtptngen.h>
 #include <unicode/measfmt.h>
 #include <unicode/msgfmt.h>
 #include <unicode/numfmt.h>
@@ -133,6 +141,9 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/search.h>
 #include <unicode/stsearch.h>
 #include <unicode/uscript.h>
+#include <unicode/uchar.h>
+#include <unicode/uversion.h>
+#include <unicode/ushape.h>
 
 #define VERSION_HEX(major, minor, patch) \
   (((major) << 24) | ((minor) << 16) | ((patch) << 8))
@@ -152,6 +163,7 @@ typedef intintobjargproc ssizessizeobjargproc;
 #if U_ICU_VERSION_HEX >= 0x04020000
 #include <unicode/tmutfmt.h>
 #include <unicode/currpinf.h>
+#include <unicode/uspoof.h>
 #endif
 
 #if U_ICU_VERSION_HEX >= 0x04040000
@@ -170,6 +182,11 @@ typedef intintobjargproc ssizessizeobjargproc;
 #if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
 #include <unicode/compactdecimalformat.h>
 #include <unicode/unum.h>
+#include <unicode/udisplaycontext.h>
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+#include <unicode/reldatefmt.h>
 #endif
 
 #if U_ICU_VERSION_HEX < 0x04060000
@@ -231,6 +248,7 @@ private:
     PyObject *msg;
 public:
     EXPORT ICUException();
+    EXPORT ICUException(const ICUException &e);
     EXPORT ICUException(UErrorCode status);
     EXPORT ICUException(UErrorCode status, char *format, ...);
     EXPORT ICUException(UParseError &pe, UErrorCode status);
@@ -238,7 +256,7 @@ public:
     EXPORT PyObject *reportError();
 };
 
-EXPORT PyObject *PyUnicode_FromUnicodeString(UnicodeString *string);
+EXPORT PyObject *PyUnicode_FromUnicodeString(const UnicodeString *string);
 EXPORT PyObject *PyUnicode_FromUnicodeString(const UChar *chars, int size);
 
 EXPORT UnicodeString &PyBytes_AsUnicodeString(PyObject *object,
