@@ -105,6 +105,11 @@ static PyObject *t_numberformat_setMaximumFractionDigits(t_numberformat *self,
 static PyObject *t_numberformat_getMinimumFractionDigits(t_numberformat *self);
 static PyObject *t_numberformat_setMinimumFractionDigits(t_numberformat *self,
                                                         PyObject *arg);
+#if U_ICU_VERSION_HEX >= 0x04080000
+static PyObject *t_numberformat_isLenient(t_numberformat *self);
+static PyObject *t_numberformat_setLenient(t_numberformat *self,
+                                           PyObject *arg);
+#endif
 static PyObject *t_numberformat_getCurrency(t_numberformat *self);
 static PyObject *t_numberformat_setCurrency(t_numberformat *self,
                                             PyObject *arg);
@@ -134,6 +139,10 @@ static PyMethodDef t_numberformat_methods[] = {
     DECLARE_METHOD(t_numberformat, setMaximumFractionDigits, METH_O),
     DECLARE_METHOD(t_numberformat, getMinimumFractionDigits, METH_NOARGS),
     DECLARE_METHOD(t_numberformat, setMinimumFractionDigits, METH_O),
+#if U_ICU_VERSION_HEX >= 0x04080000
+    DECLARE_METHOD(t_numberformat, isLenient, METH_NOARGS),
+    DECLARE_METHOD(t_numberformat, setLenient, METH_O),
+#endif
     DECLARE_METHOD(t_numberformat, getCurrency, METH_NOARGS),
     DECLARE_METHOD(t_numberformat, setCurrency, METH_O),
     DECLARE_METHOD(t_numberformat, createInstance, METH_VARARGS | METH_CLASS),
@@ -595,7 +604,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         }
         if (!parseArgs(args, "L", &l))
         {
-	  self->object->format((int64_t) l, _u);
+          self->object->format((int64_t) l, _u);
             return PyUnicode_FromUnicodeString(&_u);
         }
         break;
@@ -615,7 +624,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         if (!parseArgs(args, "LP", TYPE_CLASSID(FieldPosition),
                        &l, &fp))
         {
-	  self->object->format((int64_t) l, _u, *fp);
+          self->object->format((int64_t) l, _u, *fp);
             return PyUnicode_FromUnicodeString(&_u);
         }
         break;
@@ -635,7 +644,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         if (!parseArgs(args, "LUP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &fp))
         {
-	  self->object->format((int64_t) l, *u, *fp);
+          self->object->format((int64_t) l, *u, *fp);
             Py_RETURN_ARG(args, 1);
         }
         break;
@@ -902,6 +911,30 @@ static PyObject *t_numberformat_setMinimumFractionDigits(t_numberformat *self,
     return PyErr_SetArgsError((PyObject *) self, "setMinimumFractionDigits", arg);
 }
 
+#if U_ICU_VERSION_HEX >= 0x04080000
+
+static PyObject *t_numberformat_isLenient(t_numberformat *self)
+{
+    UBool n = self->object->isLenient();
+    Py_RETURN_BOOL(n);
+}
+
+static PyObject *t_numberformat_setLenient(t_numberformat *self,
+                                           PyObject *arg)
+{
+    int b;
+
+    if (!parseArg(arg, "b", &b))
+    {
+        self->object->setLenient(b);
+        Py_RETURN_NONE;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "setLenient", arg);
+}
+
+#endif
+
 static PyObject *t_numberformat_getCurrency(t_numberformat *self)
 {
     UnicodeString u(self->object->getCurrency());
@@ -1020,7 +1053,7 @@ static PyObject *t_numberformat_getAvailableLocales(PyTypeObject *type)
         Locale *locale = (Locale *) locales + i;
         PyObject *obj = wrap_Locale(locale, 0);
         PyDict_SetItemString(dict, locale->getName(), obj);
-	Py_DECREF(obj);
+        Py_DECREF(obj);
     }
 
     return dict;
@@ -1989,7 +2022,7 @@ static PyObject *t_rulebasednumberformat_format(t_rulebasednumberformat *self,
         if (!parseArgs(args, "LSP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &_u, &fp))
         {
-	  STATUS_CALL(self->object->format((int64_t) l, *u, _v, *fp, status));
+          STATUS_CALL(self->object->format((int64_t) l, *u, _v, *fp, status));
             return PyUnicode_FromUnicodeString(&_v);
         }
       case 4:
@@ -2008,7 +2041,7 @@ static PyObject *t_rulebasednumberformat_format(t_rulebasednumberformat *self,
         if (!parseArgs(args, "LSUP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &_u, &v, &fp))
         {
-	  STATUS_CALL(self->object->format((int64_t) l, *u, *v, *fp, status));
+          STATUS_CALL(self->object->format((int64_t) l, *u, *v, *fp, status));
             Py_RETURN_ARG(args, 2);
         }
         break;
@@ -2347,15 +2380,15 @@ static PyObject *t_choiceformat_str(t_choiceformat *self)
 
 void _init_numberformat(PyObject *m)
 {
-    DecimalFormatSymbolsType.tp_richcompare =
+    DecimalFormatSymbolsType_.tp_richcompare =
         (richcmpfunc) t_decimalformatsymbols_richcmp;
 #if U_ICU_VERSION_HEX >= 0x04020000
-    CurrencyPluralInfoType.tp_richcompare =
+    CurrencyPluralInfoType_.tp_richcompare =
         (richcmpfunc) t_currencypluralinfo_richcmp;
 #endif
-    DecimalFormatType.tp_str = (reprfunc) t_decimalformat_str;
-    RuleBasedNumberFormatType.tp_str = (reprfunc) t_rulebasednumberformat_str;
-    ChoiceFormatType.tp_str = (reprfunc) t_choiceformat_str;
+    DecimalFormatType_.tp_str = (reprfunc) t_decimalformat_str;
+    RuleBasedNumberFormatType_.tp_str = (reprfunc) t_rulebasednumberformat_str;
+    ChoiceFormatType_.tp_str = (reprfunc) t_choiceformat_str;
 
     REGISTER_TYPE(DecimalFormatSymbols, m);
     REGISTER_TYPE(NumberFormat, m);
